import { createRouter, createWebHashHistory } from 'vue-router'

const doctorIframeConfig = {
    component: () => import(/* webpackChunkName: "iframe-page" */'@/components/iframePage/IframePage.vue'),
    props: route => ({ src: route.query.src, pageTitle: route.query.pageTitle })
}

const routes = [
    {
        path: '/doctor',
        name: 'Home',
        redirect: '/doctor/workbench'
    },
    {
        path: '/resident',
        name: 'resident',
        component: () => import(/* webpackChunkName: "resident" */ '@/resident/Resident.vue'),
        children: [
            {
                path: 'screening/first/agree',
                name: 'resident-screening-first-agree',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/agree/Agree.vue')
            },
            {
                path: 'screening/first/form',
                name: 'resident-screening-first-form',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/form/Index.vue')
            },
            {
                path: 'screening/first/detail',
                name: 'resident-screening-first-detail',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/detail/List.vue')
            },
            {
                path: 'screening/first/detail/:id',
                name: 'resident-screening-first-detail-id',
                component: () => import(/* webpackChunkName: "resident-screening" */ '@/resident/screening/first/detail/Detail.vue')
            }


        ]
    },
    {
        path: '/doctor',
        name: 'doctor',
        component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/Doctor'),
        children: [
            {
                path: 'workbench',
                name: 'doctor-workbench',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/workbench/Workbench.vue')
            },
            {
                path: 'search',
                name: 'doctor-search',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/search/Search.vue')
            },
            {
                path: 'patient-detail',
                name: 'doctor-patient-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/patientDetail/PatientDetail.vue')
            },
            {
                path: 'archives-form',
                name: 'doctor-archives-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/archives/form/BaseInfo.vue')
            },
            {
                path: 'screening/firstForm',
                name: 'screening-first-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/first/FirstForm.vue')
            },
            {
                path: 'screening/firstDetail',
                name: 'screening-firstDetail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/detail/FirstDetail.vue')
            },
            {
                path: 'screening/secondForm',
                name: 'screening-second-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/second/SecondForm.vue')
            },
            {
                path: 'screening/secondDetail',
                name: 'screening-secondDetail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/detail/SecondDetail.vue')
            },

            {
                path: 'screening/highVisit/firstForm',
                name: 'screening-highVisit-first-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/highVisit/first/FirstForm.vue')
            },
            {
                path: 'screening/highVisit/firstDetail',
                name: 'screening-highVisit-firstDetail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/highVisit/detail/FirstDetail.vue')
            },
            {
                path: 'screening/highVisit/secondForm',
                name: 'screening-highVisit-second-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/highVisit/second/SecondForm.vue')
            },
            {
                path: 'screening/highVisit/secondDetail',
                name: 'screening-highVisit-secondDetail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/highVisit/detail/SecondDetail.vue')
            },
            {
                path: 'screening/highVisit/GeneralFUDetail',
                name: 'screening-highVisit-GeneralFUDetail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/screening/highVisit/detail/GeneralFUDetail')
            },
            {
                path: 'followUp/detail',
                name: 'followUp-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/detail/FollowUpDetail')
            },
            {
                path: 'followUp/generalFU/add',
                name: 'followUp-generalFU-add',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/generalFU/form/Index')
            },
            {
                path: 'diagnose/form',
                name: 'diagnose-form',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/diagnose/form/DiagnoseForm.vue')
            },
            {
                path: 'diagnose/detail',
                name: 'diagnose-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/diagnose/detail/DiagnoseDtail.vue')
            },
            {
                path: 'deathRecord/add',
                name: 'deathRecord-add',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/deathRecord/form/Index.vue')
            },
            {
                path: 'deathRecord/detail',
                name: 'deathRecord-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/deathRecord/detail/Detail')
            },
            // 专病随访
            {
                path: 'followUp/separateFU/add',
                name: 'followUp-separateFU-add',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/separateFU/form/Index')
            },
            //慢特病随访
            {
                path: 'followUp/slowSpecialFU/detail',
                name: 'followUp-slowSpecialFU-detail',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/slowSpecialFU/detail/Detail')
            },
            {
                path: 'followUp/slowSpecialFU/add',
                name: 'followUp-slowSpecialFU-add',
                component: () => import(/* webpackChunkName: "doctor" */ '@/doctor/followUp/slowSpecialFU/form/Index')
            },
        ]
    },
    {
        path: '/residentWX',
        name: 'residentWX',
        component: () => import(/* webpackChunkName: "residentWX" */ '@/residentWX/ResidentWX.vue'),
        children: [
            {
                path: 'screening/list',
                name: 'residentWX-screening-list',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/List.vue')
            },
            {
                path: 'screening/firstDetail/:id',
                name: 'resident-screening-firstDetail',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/detail/FirstDetail.vue')
            },
            {
                path: 'screening/secondDetail/:id',
                name: 'resident-screening-secondDetail',
                component: () => import(/* webpackChunkName: "residentWX-screening" */ '@/residentWX/screening/detail/SecondDetail.vue')
            },
            {
                path: 'visit/list',
                name: 'residentWX-visit-List',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/List.vue')
            },
            //通用随访详情
            {
                path: 'visit/GeneralFUDetail/:relationId',
                name: 'resident-visit-GeneralFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/GeneralFUDetail.vue')
            },
            //主要慢病高危详情
            {
                path: 'visit/FirstFUDetail/:id',
                name: 'resident-visit-FirstFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/FirstFUDetail.vue')
            },
            //专病高危详情
            {
                path: 'visit/SecondFUDetail/:id',
                name: 'resident-visit-SecondFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/SecondFUDetail.vue')
            },
            // 专病随访详情
            {
                path: 'visit/SeparateFUDetail/:relationId/:diseaseType',
                name: 'resident-visit-SeparateFUDetail',
                component: () => import(/* webpackChunkName: "residentWX-visit" */ '@/residentWX/visit/detail/SeparateFUDetail.vue')
            },
            // 健康指导宣教
            {
                path: 'guide/list',
                name: 'residentWX-guide-list',
                component: () => import(/* webpackChunkName: "residentWX-guide" */ '@/residentWX/guide/List.vue')
            },
            {
                path: 'guide/list/:id',
                name: 'residentWX-guide-Detail',
                component: () => import(/* webpackChunkName: "residentWX-guide" */ '@/residentWX/guide/Detail.vue')
            },
            {
                path: 'nim',
                name: 'residentWX-nim',
                component: () => import(/* webpackChunkName: "residentWX-nim" */ '@/residentWX/nim/Index.vue'),
            },
            {
                path: 'nim/:id',
                name: 'residentWX-nim-session',
                component: () => import(/* webpackChunkName: "residentWX-nim" */ '@/residentWX/nim/Session.vue'),
            }
        ]
    },
    { path: '/systemIframe/:stat', name: 'systemIframe', ...doctorIframeConfig},
    {
        path: '/test',
        name: 'Test',
        component: () => import(/* webpackChunkName: "test" */ '@/test/Index.vue'),
    }
]

const router = createRouter({
    history: createWebHashHistory(),
    routes
})

export default router
